@@ -1,5 +1,5 @@
 package HackaMol::Roles::AtomGroupRole;
-$HackaMol::Roles::AtomGroupRole::VERSION = '0.027';
+$HackaMol::Roles::AtomGroupRole::VERSION = '0.028';
 #ABSTRACT: Role for a group of atoms
 use Moose::Role;
 use Carp;
@@ -36,6 +36,13 @@ has 'atoms' => (
     lazy => 1,
 );
 
+has 'is_constrained' => (
+    is      => 'rw',
+    isa     => 'Bool',
+    lazy    => 1,
+    default => 0,
+);
+
 sub dipole {
     my $self = shift;
     return ( V(0) ) unless ( $self->count_atoms );
@@ -372,7 +379,7 @@ HackaMol::Roles::AtomGroupRole - Role for a group of atoms
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 SYNOPSIS
 
